@@ -74,15 +74,6 @@ CodeCompletionModel::CodeCompletionModel( QObject * parent )
   setForceWaitForModel(true);
 }
 
-KTextEditor::CodeCompletionModelControllerInterface2::MatchReaction CodeCompletionModel::matchingItem(const QModelIndex& matched) {
-  KSharedPtr<CompletionTreeElement> element = itemForIndex(matched);
-  //Do not hide the completion-list if the matched item is an implementation-helper
-  if(dynamic_cast<ImplementationHelperItem*>(element.data()))
-    return KTextEditor::CodeCompletionModelControllerInterface2::None;
-  else
-    return CodeCompletionModelControllerInterface2::matchingItem(matched);
-}
-
 bool CodeCompletionModel::shouldStartCompletion(KTextEditor::View* view, const QString& inserted, bool userInsertion, const KTextEditor::Cursor& position) {
   kDebug() << inserted;
   QString insertedTrimmed = inserted.trimmed();
