@@ -28,16 +28,19 @@
 #include <KUrl>
 #include <KMessageBox>
 #include <KLocale>
+#include <KTemporaryFile>
 
 #include <interfaces/icore.h>
 #include <interfaces/idocumentcontroller.h>
 #include <language/duchain/identifier.h>
 #include <language/duchain/declaration.h>
 #include <language/duchain/classmemberdeclaration.h>
+#include <language/duchain/classfunctiondeclaration.h>
 #include <language/duchain/duchain.h>
 #include <language/duchain/duchainlock.h>
 #include <language/duchain/persistentsymboltable.h>
 #include <language/duchain/classdeclaration.h>
+#include <language/duchain/duchainutils.h>
 #include <language/codegen/documentchangeset.h>
 #include <language/codegen/coderepresentation.h>
 
@@ -49,6 +52,7 @@
 #include <QVBoxLayout>
 #include <QListWidget>
 #include <QLabel>
+#include <QTreeWidget>
 
 #include "../codecompletion/implementationhelperitem.h"
 #include "../codecompletion/missingincludeitem.h"
@@ -71,11 +75,56 @@ QualifiedIdentifier CppClassIdentifierPage::parseParentClassId(const QString & i
   return QualifiedIdentifier(identifier);
 }
 
-CppOverridesPage::CppOverridesPage(QWizard* parent)
-  : KDevelop::OverridesPage(parent)
+CppOverridesPage::CppOverridesPage(ClassGenerator* generator, QWizard* parent)
+  : KDevelop::OverridesPage(generator, parent)
 {
 }
 
+void CppOverridesPage::populateOverrideTree(const QList< DeclarationPointer >& baseList)
+{
+  OverridesPage::populateOverrideTree(baseList);
+
+  // add standard functions that most classes need
+  // we need some context first though...
+  const QString newClass = generator()->name();
+
+  // generate CPP code with default methods and get a context for that
+  KTemporaryFile file;
+  file.setSuffix( ".cpp" );
+  file.setAutoRemove(false);
+  file.open();
+  QTextStream stream(&file);
+  stream << "class " << newClass << " {\n"
+       << "  public:\n"
+       // default ctor
+       << "    " << newClass << "();\n"
+       // copy ctor
+       << "    " << newClass << "(const " << newClass << "& other);\n"
+       // default dtor
+       << "    ~" << newClass << "();\n"
+       // assignment operator
+       << "    " << newClass << "& operator=(const " << newClass << "& other);\n"
+       // equality operator
+       << "    bool operator==(const " << newClass << "& other) const;\n"
+       << "};\n";
+  file.close();
+  ReferencedTopDUContext context(DUChain::self()->waitForUpdate( IndexedString(file.fileName()), KDevelop::TopDUContext::AllDeclarationsAndContexts ));
+  DUChainReadLocker lock;
+
+  if (!context || !context->childContexts().size() == 1) {
+    kWarning() << "invalid context for generated cpp file with default methods" << file.fileName();
+    return;
+  }
+
+  // add items
+  QTreeWidgetItem* defaultItems = new QTreeWidgetItem(overrideTree(), QStringList() << i18n("Default Methods"));
+  foreach( Declaration* dec, context->childContexts().first()->localDeclarations() ) {
+    addPotentialOverride(defaultItems, DeclarationPointer(dec));
+  }
+
+  file.remove();
+}
+
 void CppOverridesPage::addPotentialOverride(QTreeWidgetItem* classItem, KDevelop::DeclarationPointer childDeclaration)
 {
   // HACK: filter out Qt's moc calls
@@ -99,7 +148,7 @@ CppClassIdentifierPage* CppNewClassWizard::newIdentifierPage()
 
 CppOverridesPage* CppNewClassWizard::newOverridesPage()
 {
-  return new CppOverridesPage(this);
+  return new CppOverridesPage(generator(), this);
 }
 
 KDevelop::DocumentChangeSet CppNewClass::generate()
@@ -134,9 +183,8 @@ KDevelop::DocumentChangeSet CppNewClass::generate()
       p->buildSystemManager()->features() & KDevelop::IBuildSystemManager::Targets )
   {
     QList<KDevelop::ProjectTargetItem*> t=folder->targetList();
-    for(QStandardItem* it=folder; it && t.isEmpty(); it=it->parent()) {
-      KDevelop::ProjectBaseItem* bit=static_cast<KDevelop::ProjectBaseItem*>(it);
-      t=bit->targetList();
+    for(ProjectBaseItem* it=folder; it && t.isEmpty(); it=it->parent()) {
+      t=it->targetList();
     }
     if(t.count()==1) //Just choose this one
       target=t.first();
@@ -208,10 +256,10 @@ void CppNewClass::clearInheritance()
     m_baseAccessSpecifiers.clear();
 }
 
-void CppNewClass::identifier(const QString & identifier)
+void CppNewClass::setIdentifier(const QString & identifier)
 {
   QStringList list = identifier.split("::");
-  name(list.last());
+  setName(list.last());
   m_objectType->setDeclarationId(DeclarationId(QualifiedIdentifier(name())));
   list.pop_back();
   m_namespaces = list;
@@ -228,7 +276,7 @@ void CppNewClass::setType(Type type)
 }
 
 
-QString CppNewClass::identifier(void) const
+QString CppNewClass::identifier() const
 {
   QString identifier = m_namespaces.join("::");
   
@@ -266,7 +314,7 @@ void CppNewClass::generateHeader(KDevelop::DocumentChangeSet& changes)
   kDebug() << "base-classes:" << m_baseClasses.size();
   
   if(!license().isEmpty())
-    output << (addCommentCharToLicense() ? "/*\n" : "") << license() << (addCommentCharToLicense() ? "\n*/" : "") << "\n\n";
+    output << license() << "\n\n";
 
   Identifier classId = Identifier(name());
 
@@ -367,7 +415,7 @@ void CppNewClass::generateHeader(KDevelop::DocumentChangeSet& changes)
     if(override->type<FunctionType>())
     {
       Cpp::ImplementationHelperItem item(Cpp::ImplementationHelperItem::Override, override);
-      output << item.insertionText() << "\n";
+      output << item.insertionText(KUrl(), SimpleCursor(), QualifiedIdentifier(classId)) << "\n";
     }
     else
       output << override->toString() << ";\n";
@@ -451,7 +499,7 @@ void CppNewClass::generateImplementation(KDevelop::DocumentChangeSet& changes)
   QTextStream output(&implementation, QIODevice::WriteOnly);
 
   if(!license().isEmpty())
-    output << (addCommentCharToLicense() ? "/*\n" : "") << license() << (addCommentCharToLicense() ? "\n*/" : "") << "\n\n";
+    output << license() << "\n\n";
 
   // #include our header
   QString path = KUrl::relativePath(implementationUrl().directory(), headerUrl().toLocalFile());
