@@ -171,6 +171,9 @@ CppLanguageSupport::CppLanguageSupport( QObject* parent, const QVariantList& /*a
 //     Cpp::EnvironmentManager::self()->setMatchingLevel(Cpp::EnvironmentManager::Naive);
 //     Cpp::EnvironmentManager::self()->setMatchingLevel(Cpp::EnvironmentManager::Full);
 
+    CppUtils::standardMacros();
+    CppUtils::standardIncludePaths();
+
     m_includeResolver = new CppTools::IncludePathResolver;
 
     m_quickOpenDataProvider = new IncludeFileDataProvider();
