@@ -354,7 +354,7 @@ QList<KDevelop::ProjectFolderItem*> CMakeManager::parse( KDevelop::ProjectFolder
     KUrl cmakeListsPath(folder->url());
     cmakeListsPath.addPath("CMakeLists.txt");
     
-    if(folder && folder->type()==KDevelop::ProjectBaseItem::BuildFolder && QFile::exists(cmakeListsPath.toLocalFile()))
+    if(folder && QFile::exists(cmakeListsPath.toLocalFile()))
     {
         kDebug(9042) << "parse:" << folder->url();
         
@@ -562,7 +562,7 @@ QList<KDevelop::ProjectFolderItem*> CMakeManager::parse( KDevelop::ProjectFolder
             KUrl::List tfiles;
             foreach( const QString & sFile, t.files)
             {
-                if(sFile.isEmpty())
+                if(sFile.startsWith("#[") || sFile.isEmpty())
                     continue;
 
                 KUrl sourceFile(sFile);
@@ -578,6 +578,9 @@ QList<KDevelop::ProjectFolderItem*> CMakeManager::parse( KDevelop::ProjectFolder
             
             setTargetFiles(targetItem, tfiles);
         }
+    } else {
+        folder->cleanupBuildFolders(QList<Subdirectory>());
+        folder->cleanupTargets(QList<CMakeTarget>());
     }
     reloadFiles(folder);
 
@@ -751,18 +754,18 @@ bool CMakeManager::isReloading(IProject* p)
 void CMakeManager::deletedWatched(const QString& path)
 {
     KUrl dirurl(path);
-    dirurl.adjustPath(KUrl::AddTrailingSlash);
     IProject* p=ICore::self()->projectController()->findProjectForUrl(dirurl);
     
     if(p) {
+        dirurl.adjustPath(KUrl::AddTrailingSlash);
         if(p->folder()==dirurl)
             ICore::self()->projectController()->closeProject(p);
         else if(!isReloading(p)) {
             KUrl url(path);
             
             if(path.endsWith("/CMakeLists.txt")) {
-                QList<ProjectFolderItem*> folders = p->foldersForUrl(url.upUrl().upUrl());
-                foreach(ProjectFolderItem* folder, folders)
+                QList<ProjectFolderItem*> folders = p->foldersForUrl(url.upUrl());
+                foreach(ProjectFolderItem* folder, folders) 
                     reload(folder);
                 
             } else {
@@ -857,7 +860,7 @@ void CMakeManager::reloadFiles(ProjectFolderItem* item)
         return;
     }
     
-    QStringList entriesL = d.entryList( QDir::AllEntries | QDir::NoDotAndDotDot );
+    QStringList entriesL = d.entryList( QDir::AllEntries | QDir::NoDotAndDotDot | QDir::NoSymLinks);
     QSet<QString> entries = filterFiles(entriesL);
     
     KUrl folderurl = item->url();
@@ -890,12 +893,14 @@ void CMakeManager::reloadFiles(ProjectFolderItem* item)
                     break;
             }
         }
-        else if(it->url()!=fileurl) {
-            it->setUrl(fileurl);
-            ProjectFolderItem* folder = it->folder();
-            
-            if(folder)
-                reloadFiles(folder);
+        else {
+            if(it->url()!=fileurl) {
+                it->setUrl(fileurl);
+                if(ProjectFolderItem* folder = it->folder())
+                    reloadFiles(folder);
+            }
+            // reduce amount of checks done when looking for new items
+            entries.remove(current);
         }
     }
     
@@ -904,12 +909,11 @@ void CMakeManager::reloadFiles(ProjectFolderItem* item)
     {
         KUrl fileurl = folderurl;
         fileurl.addPath( entry );
-        
-        if( item->hasFileOrFolder( entry ) )
-        {
-            continue;
-        }
-        else if( QFileInfo( fileurl.toLocalFile() ).isDir() )
+
+        // existing entries should have been removed above already
+        Q_ASSERT( !item->hasFileOrFolder( entry ) );
+
+        if( QFileInfo( fileurl.toLocalFile() ).isDir() )
         {
             fileurl.adjustPath(KUrl::AddTrailingSlash);
             ProjectFolderItem* pendingfolder = m_pending.take(fileurl);
@@ -918,6 +922,7 @@ void CMakeManager::reloadFiles(ProjectFolderItem* item)
                 item->appendRow(pendingfolder);
             } else if(isCorrectFolder(fileurl, item->project())) {
                 fileurl.adjustPath(KUrl::AddTrailingSlash);
+                m_watchers[item->project()]->addDir(fileurl.toLocalFile(), KDirWatch::WatchFiles);
                 reloadFiles(new ProjectFolderItem( item->project(), fileurl, item ));
             }
         }
@@ -1028,8 +1033,10 @@ CacheValues CMakeManager::readCache(const KUrl &path) const
         {
             CacheLine c;
             c.readLine(line);
-            if(c.flag().isEmpty())
+            if(c.flag().isEmpty()) {
                 ret[c.name()]=CacheEntry(c.value(), currentComment.join("\n"));
+                currentComment.clear();
+            }
 //             kDebug(9042) << "Cache line" << line << c.name();
         }
         else if(line.startsWith("//"))
